--------------------------------------------------------------------
--	TradeskillSwitcher_HasSpell
--	Boolean for if spell is in spellbook (can include tradeskill window)
--
--	PARAMETERS:
--	ThisSpell - String - Name of spell
--
--	RETURNS:
--	SpellInBook - Boolean - True only if spell is in spellbook.
--
local function TradeskillSwitcher_HasSpell(ThisSpell)
	local retOK = GetSpellInfo(ThisSpell)
	if retOK then return true end
	return false
end

--------------------------------------------------------------------
--	Slash Command: TRADESKILLSWITCHER
--	Cycles through available tradeskill windows
--
--	PARAMETERS:
--	msg - parameters supplied on line with slash command. Used to
--		  determine if conditionals have been supplied and if pass.
--	editbox - Unused. Required by slash command functions.
--
SLASH_TRADESKILLSWITCHER1 = "/tsswitch"
SLASH_TRADESKILLSWITCHER2 = "/tradeskillswitcher"
function SlashCmdList.TRADESKILLSWITCHER(msg, editbox)
	local tsArgv, _ = SecureCmdOptionParse(msg)
	if (tsArgv == nil) then return end

	local TSNum = 0
	local TStoOpen = ""
	local OpenTS = GetTradeSkillLine()
	
	-- Set tradeskill names to reversible array
	local TSvsNum = {}
	TSvsNum[1] = "Alchemy"
	TSvsNum[2] = "Blacksmithing"
	TSvsNum[3] = "Tailoring"
	TSvsNum[4] = "Engineering"
	TSvsNum[5] = "Leatherworking"
	TSvsNum[6] = "Jewelcrafting"
	TSvsNum[7] = "Inscription"
	TSvsNum[8] = "Enchanting"
	TSvsNum[9] = "Mining"
	TSvsNum[10] = "Cooking"
	TSvsNum[11] = "First Aid"
	TSvsNum[12] = "Archaeology"
	TSvsNum[13] = "Runeforging"
	for i=1, getn(TSvsNum) do TSvsNum[TSvsNum[i]] = i end

	-- Determines which, if any, tradeskill window is open
	if (OpenTS ~= "UNKNOWN") then TSNum = TSvsNum[OpenTS]
	elseif (ArchaeologyFrame and ArchaeologyFrame:IsVisible()) then TSNum = TSvsNum["Archaeology"]
	else TSNum = 0
	end

	-- Determines next available tradeskill in list to open
	TSNum = TSNum + 1
	for TSCounter = TSNum, 13 do
		if (TStoOpen == "") then 
			local spellName = TSvsNum[TSCounter]
			if spellName == "Mining" then spellName = "Smelting" end
			if TradeskillSwitcher_HasSpell(spellName) then TStoOpen = spellName end
		end
	end

	-- Opens that tradeskill window, or if no tradeskill is found before end of list, closes all tradeskill windows
	if (TStoOpen == "Archaeology") then CloseTradeSkill() end
	if (TStoOpen ~= "Archaeology" and ArchaeologyFrame and ArchaeologyFrame:IsVisible()) then HideUIPanel(ArchaeologyFrame) end
	if (TStoOpen ~= "") then
		CastSpellByName(TStoOpen)
	else
		CloseTradeSkill()
	end
end